Changelog
=========

0.7.2 (2018-10-11)
------------------

- Fix url for search on openstreetmap .
  [bsuttor]


0.7.1 (2015-06-25)
------------------

- Set all JavaScript registrations to cachable and cookable True.
  [thet]

- Remove leaflet.ie.css, as it was removed from Leaflet.
  [thet]


0.7 (2014-08-26)
----------------

- Update Leaflet version of this package (now 0.7.3).
  [bsuttor]


0.6 (2014-04-30)
----------------

- Laflet + Plugins update from 2013-06-24.
  [thet]


0.5 (2013-06-11)
----------------

- Add some interesting plugins and introduce bundle concept to enable
  individual plugins.
  [thet]

- New Leaflet resource structure: Get source directly from Github and adapt the
  resource directory to use the new subdirectory. This change is backwards
  compatible.
  [thet]

- PEP8 Cleanup.
  [thet]


0.4.4.1 (2012-09-24)
--------------------

- Fix CSS images urls [ebrehault]

0.4.4 (2012-09-13)
------------------

- Upgrade to Leaflet 0.4.4 [ebrehault]
- Note: we now use the Leaflet lib version as egg version.

0.3.3 (2012-09-03)
------------------

- Fix egg [ebrehault]

0.3.2 (2012-08-02)
------------------

- Upgrade to Leaflet 0.4 [ebrehault]

0.3.1.5 (unreleased)
--------------------

- Nothing changed yet.


0.3.1.4 (2012-02-24)
--------------------

- Fix background urls


0.3.1.3 (2012-02-24)
--------------------
- FIX: Enable ie css only on ie [kiorky]

0.3.1.2 (2012-02-24)
--------------------

- Fix for plone < 41 [kiorky]


0.3.1 (2012-02-23)
------------------

- Initial release [kiorky]

